/**********************************************************************************
 * Module name              : CapLed_Operation.c
 * Module ID                : 
 * Purpose of the module    : All LED operations and Timer ISR is implemented in this module
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Modification History     :
 * (To be repeated for every Modification done)
 *                >   Revision                 : 1.0
 *                >   Purpose of Modification  : Initial Version
 *                >   Modification details     : NA
 *                >   Modified date            : 20/12/2017
 *                >   Modified by              : PK
 *********************************************************************************/

/*** include files ***/
#include <stdio.h>
#include <stdint.h>
#include <cytypes.h>
#include <I2C_I2C.h>
#include <CapSense.h>
#include <cyapicallbacks.h>
#include <CapSense_CSHL.h>
#include <CapLed_Operation.h>
#include <Capswitch_Operation.h>
#include <Timer.h>

/*** Global Variable declarations ***/
volatile uint16 g_unTimer_Counter=ZERO;
volatile uint16 g_unTimer_Counter_Capsense=ZERO;
static uint16 g_unSurface_Count=ZERO;
static uint16 g_unDeep_Count=ZERO;
static uint16 g_unCatalyst_Count=ZERO;
static uint16 g_unStopOpen_Count=ZERO;
static uint16 g_unAllLed_Count=ZERO;
static uint8 g_ucAllLed_Noperations=ZERO;

/******************************** Function Definitions ***********************************/

/**********************************************************************************
 * Module name              : CY_ISR(InterruptHandler)
 * Module ID                : 
 * Purpose of the module    : When defining ISR functions, 
                              the CY_ISR and CY_ISR_PROTO macros should be 
 *                            used to provide consistent definition across compilers
                              (configuring the ISR as timer ISR)  
 * Author/s                 : Cypress
 * Date written             : 20/12/2017
 * Global Variables Referred: g_unTimer_Counter
 * Global Variables Modified: g_unTimer_Counter  
 * Functions called         : None
 * Arguments                : InterruptHandler
 * Return Values            : None
 *********************************************************************************/
CY_ISR(InterruptHandler)
{
       /* Check interrupt source */
    if (Timer_INTR_MASK_CC_MATCH == Timer_GetInterruptSourceMasked())
    {
        /* Clear interrupt and then process Capture interrupt */
        Timer_ClearInterrupt(Timer_INTR_MASK_CC_MATCH);
    }
    else
    {
        
        g_unTimer_Counter++;
        g_unTimer_Counter_Capsense++;
 
        /* Clear interrupt and then process Terminal Count interrupt */
        Timer_ClearInterrupt(Timer_INTR_MASK_TC);
        
    } 
}

/**********************************************************************************
 * Module name              : PerformLedOperation()
 * Module ID                : 
 * Purpose of the module    : Handles LED's operation(ON,OFF,BLINk,ONE SHOT)
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: et_capsen_ALL_ledoperation,g_ucAllLed_Noperations                              
 * Global Variables Modified: et_capsen_ALL_ledoperation,g_ucAllLed_Noperations  
 * Functions called         : LED_init(),CapLed_SetSurfaceLed(),CapLed_SetDeepLed(),
                              CapLed_SetCatalystLed(),CapLed_SetStopOpenLed(),
                              CapAll_LEDToggleOperation() 
 * Arguments                : None
 * Return Values            : None
 *********************************************************************************/
void PerformLedOperation()
{
    /* Execute individual LEDs if All LED operation is not active */
    if(et_capsen_ALL_ledoperation == NO_OPERATION)
    {
        if(g_ucAllLed_Noperations == ONE) /* Clear all LED operations*/
        {
            LED_init(); 
            g_ucAllLed_Noperations = ZERO;
            
        }
        CapLedSetSurfaceLed();
        CapLedSetDeepLed();
        CapLedSetCatalystLed();
        CapLedSetStopOpenLed();   
    }
    /* Execute All LED operation */
    else
    {
        CapAllLEDOperation();  
    }
}

/**********************************************************************************
 * Module name              : CapLedSetSurfaceLed()
 * Module ID                : 
 * Purpose of the module    : Handles Surface LED operations(ON,OFF,BLINK,ONESHOT) 
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: et_capsen_SURFACE_LED_operation,g_unSurface_Count,
                              g_unSurface_Led_period
 * Global Variables Modified: et_capsen_SURFACE_LED_operation,g_unSurface_Count,
                              g_unSurface_Led_period  
 * Functions called         : LED1_Write,LED1_Read
 * Arguments                : None
 * Return Values            : None
 *********************************************************************************/
void CapLedSetSurfaceLed()
{

    /* check if Surface LED to be in blink state */
    if(et_capsen_SURFACE_LED_operation == CAPSENSE_LED_BLINK)
    {
        g_unSurface_Count+=FIVE;

        if( g_unSurface_Count >= (g_unSurface_Led_period/TWO) )
        {
            LED1_Write(!LED1_Read());
            g_unSurface_Count=ZERO;
        }
        else{}
    }
    /* check if Surface LED to be in one shot state */
    else if(et_capsen_SURFACE_LED_operation == CAPSENSE_LED_ONESHOT)
    {
        if(g_unSurface_Count <= g_unSurface_Led_period )
        {
             LED1_Write(ZERO);  
             g_unSurface_Count+=FIVE;          
        }
        else
        {
            LED1_Write(ONE);
            g_unSurface_Count=ZERO;
            et_capsen_SURFACE_LED_operation = OTHER_OPERATION;                   
        }
    }
    /* check if Surface LED to be noe of the states(ON,OFF,BLINK,ONESHOT) */    
    else if(et_capsen_SURFACE_LED_operation == OTHER_OPERATION)
    {
        /* Do Nothing */  
    }
    else{}
}

/**********************************************************************************
 * Module name              : CapLedSetDeepLed()
 * Module ID                : 
 * Purpose of the module    : Handles Deep LED operations(ON,OFF,BLINK,ONESHOT) 
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: et_capsen_DEEP_LED_operation,g_unDeep_Count,
                              g_unDeep_Led_period
 * Global Variables Modified: et_capsen_DEEP_LED_operation,g_unDeep_Count,
                              g_unDeep_Led_period  
 * Functions called         : LED2_Write,LED2_Read
 * Arguments                : None
 * Return Values            : None
 *********************************************************************************/
void CapLedSetDeepLed()
{

    /* check if Deep LED to be in Blink state */
    if(et_capsen_DEEP_LED_operation == CAPSENSE_LED_BLINK)
    {
        g_unDeep_Count+=FIVE;
        if( g_unDeep_Count >= (g_unDeep_Led_period/TWO) )
        {
            LED2_Write(!LED2_Read());
            g_unDeep_Count=ZERO;
        }
        else{}
    }
    /* check if Deep LED to be in One shot state */
    else if(et_capsen_DEEP_LED_operation == CAPSENSE_LED_ONESHOT)
    {
        if( g_unDeep_Count <= g_unDeep_Led_period )
        {
            LED2_Write(ZERO);  
            g_unDeep_Count+=FIVE;          
        }
        else
        {
            LED2_Write(ONE);
            g_unDeep_Count=ZERO;
            et_capsen_DEEP_LED_operation = OTHER_OPERATION; 
        }
    }
    /* check if Deep LED to be in none of state(ON,OFF,BLINK,ONESHOT) */    
    else if(et_capsen_DEEP_LED_operation == OTHER_OPERATION)
    {        
        /* Do Nothing */        
    }
    else{}
}

/**********************************************************************************
 * Module name              : CapLedSetCatalystLed()
 * Module ID                : 
 * Purpose of the module    : Handles Catalyst LED operations(ON,OFF,BLINK,ONESHOT) 
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: et_capsen_CATALYST_LED_operation,g_unCatalyst_Count,
                              g_unCatalyst_Led_period
 * Global Variables Modified: et_capsen_CATALYST_LED_operation,g_unCatalyst_Count,
                              g_unCatalyst_Led_period 
 * Functions called         : LED3_Write,LED3_Read
 * Arguments                : None
 * Return Values            : None
 *********************************************************************************/
void CapLedSetCatalystLed()
{

    /* check if Catalyst LED to be in Blink state */ 
    if(et_capsen_CATALYST_LED_operation == CAPSENSE_LED_BLINK)
    {
        g_unCatalyst_Count+=FIVE;
        if( g_unCatalyst_Count >= (g_unCatalyst_Led_period/TWO) )
            {
                LED3_Write(!LED3_Read());
                g_unCatalyst_Count=ZERO;
            }
        else{}                    
    }
    /* check if Catalyst LED to be in Oneshot state */
    else if(et_capsen_CATALYST_LED_operation == CAPSENSE_LED_ONESHOT)
    {
        if( g_unCatalyst_Count <= g_unCatalyst_Led_period )
        {
            LED3_Write(ZERO);  
            g_unCatalyst_Count+=FIVE;
          
        }
        else
        {
            LED3_Write(ONE);
            g_unCatalyst_Count=ZERO;
            et_capsen_CATALYST_LED_operation = OTHER_OPERATION; 
        }
    }
    /* check if Catalyst LED to be in none of state(ON,OFF,BLINK,ONESHOT) */    
    else if(et_capsen_CATALYST_LED_operation == OTHER_OPERATION)
    {        
        /* Do Nothing */        
    }
    else{}
}

/**********************************************************************************
 * Module name              : CapLedSetStopOpenLed()
 * Module ID                : 
 * Purpose of the module    : Handles Stop Open LED operations(ON,OFF,BLINK,ONESHOT) 
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: et_capsen_STOPOPEN_LED_operation,g_unStopOpen_Count,
                              g_unStopOpen_Led_period
 * Global Variables Modified: et_capsen_STOPOPEN_LED_operation,g_unStopOpen_Count,
                              g_unStopOpen_Led_period 
 * Functions called         : LED4_Write,LED4_Read
 * Arguments                : None
 * Return Values            : None
 *********************************************************************************/
void CapLedSetStopOpenLed()
{

    /* check if Stopopen LED to be in Blink state */
    if(et_capsen_STOPOPEN_LED_operation == CAPSENSE_LED_BLINK)
    {
        g_unStopOpen_Count+=FIVE;
        
        if( g_unStopOpen_Count >= (g_unStopOpen_Led_period/TWO) )
        {
            LED4_Write(!LED4_Read());
            g_unStopOpen_Count=ZERO;
        }
          else{}                   
    }
    /* check if Stopopen LED to be in one shot state */
    else if(et_capsen_STOPOPEN_LED_operation == CAPSENSE_LED_ONESHOT)
    {
        if( g_unStopOpen_Count <= g_unStopOpen_Led_period )
        {
            LED4_Write(ZERO);  
            g_unStopOpen_Count+=FIVE;
          
        }
        else
        {
            LED4_Write(ONE);
            g_unStopOpen_Count=ZERO;
            et_capsen_STOPOPEN_LED_operation = OTHER_OPERATION;            
        }
    }
    /* check if Stopopen LED to be in none of state(ON,OFF,BLINK,ONESHOT) */    
    else if(et_capsen_STOPOPEN_LED_operation == OTHER_OPERATION)
    {        
        /* Do Nothing */             
    }
    else{}
}

/**********************************************************************************
 * Module name              : CapAllLEDOperation()
 * Module ID                : 
 * Purpose of the module    : Handles ALL LED operations(ON,OFF,BLINK,ONESHOT) 
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: et_capsen_ALL_ledoperation,g_unAllLed_Count,
                              g_unAll_Led_period,et_capsen_SURFACE_LED_operation,
                              et_capsen_CATALYST_LED_operation,et_capsen_DEEP_LED_operation
                              et_capsen_STOPOPEN_LED_operation,g_ucAllLed_Noperations
 * Global Variables Modified: et_capsen_ALL_ledoperation,g_unAllLed_Count,
                              g_unAll_Led_period,et_capsen_SURFACE_LED_operation,
                              et_capsen_CATALYST_LED_operation,et_capsen_DEEP_LED_operation
                              et_capsen_STOPOPEN_LED_operation,g_ucAllLed_Noperations
 * Functions called         : LED1_Write,LED2_Write,LED3_Write,LED4_Write
                              LED1_Read,LED2_Read,LED3_Read,LED4_Read
                              LED_On(),LED_init()
                              
 * Arguments                : None
 * Return Values            : None
 *********************************************************************************/
void CapAllLEDOperation()
{
    /* check if ALL LED to be in Blink state */
    if(et_capsen_ALL_ledoperation == CAPSENSE_ALLLED_BLINK)
    {
        g_unAllLed_Count+=FIVE;
        if(g_unAllLed_Count >= (g_unAll_Led_period / TWO))
        {
            LED1_Write(!LED1_Read());
            LED2_Write(!LED2_Read());
            LED3_Write(!LED3_Read());
            LED4_Write(!LED4_Read());
            g_unAllLed_Count = ZERO;
        }
        else{}
        
    }
    /* check if ALL LED to be in one shot state */
    else if(et_capsen_ALL_ledoperation == CAPSENSE_ALLLED_ONESHOT)
    {         
        if(g_unAllLed_Count <= g_unAll_Led_period)
        {
            LED_On();
            g_unAllLed_Count+=FIVE;

        }
        else
        {
            LED_init();
            g_unAllLed_Count=ZERO;
            et_capsen_ALL_ledoperation = OTHER_OPERATION ;
        } 
    }
    /* check if ALL LED to be in none of state(ON,OFF,BLINK,ONESHOT) */
    else if(et_capsen_ALL_ledoperation == OTHER_OPERATION)
    {
        /* Do Nothing */
    }
    else{}
    /* set after all LED operations are finished for check in cyclic perform_led_operation function */
    g_ucAllLed_Noperations = ONE;
    /* set the Surface LED operation to no operation mode*/
    et_capsen_SURFACE_LED_operation = NO_OPERATION;
    /* set the Deep LED operation to no operation mode*/
    et_capsen_DEEP_LED_operation = NO_OPERATION;
    /* set the Catalyst LED operation to no operation mode*/
    et_capsen_CATALYST_LED_operation = NO_OPERATION;
    /* set the Stopopen LED operation to no operation mode*/
    et_capsen_STOPOPEN_LED_operation = NO_OPERATION;
}

/**********************************************************************************
 * Module name              : LED_init
 * Module ID                : 
 * Purpose of the module    : Tie all the LED's to OFF state 
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: None
 * Global Variables Modified: None  
 * Functions called         : LED1_Write , LED2_Write, LED3_Write,LED4_Write
 * Arguments                : None
 * Return Values            : None
 *********************************************************************************/
void LED_init()
{
    LED1_Write(ONE);
    LED2_Write(ONE);
    LED3_Write(ONE);
    LED4_Write(ONE);
}

/**********************************************************************************
 * Module name              : LED_On
 * Module ID                : 
 * Purpose of the module    : Tie all the LED's to ON state 
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: None
 * Global Variables Modified: None  
 * Functions called         : LED1_Write , LED2_Write, LED3_Write,LED4_Write
 * Arguments                : None
 * Return Values            : None
 *********************************************************************************/
void LED_On()
{
    LED1_Write(ZERO);
    LED2_Write(ZERO);
    LED3_Write(ZERO);
    LED4_Write(ZERO);
}

/**********************************************************************************
 * Module name              : GetCounterVal
 * Module ID                : 
 * Purpose of the module    : Returns the timer Counter Value
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: None
 * Global Variables Modified: None  
 * Functions called         : None
 * Arguments                : None
 * Return Values            : g_unTimer_Counter
 *********************************************************************************/
uint16  GetCounterVal()
{
    return g_unTimer_Counter;
}

/**********************************************************************************
 * Module name              : SetCounterVal
 * Module ID                : 
 * Purpose of the module    : Set the Timer counter value
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: g_unTimer_Counter
 * Global Variables Modified: g_unTimer_Counter  
 * Functions called         : None
 * Arguments                : unClearcounter
 * Return Values            : None
 *********************************************************************************/
void SetCounterVal(uint16 unClearcounter)
{
    g_unTimer_Counter = unClearcounter;
}

/**********************************************************************************
 * Module name              : GetCounterValCapsense
 * Module ID                : 
 * Purpose of the module    : Returns the timer Counter Value
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: None
 * Global Variables Modified: None  
 * Functions called         : None
 * Arguments                : None
 * Return Values            : g_unTimer_Counter
 *********************************************************************************/
uint16  GetCounterValCapsense()
{
    return g_unTimer_Counter_Capsense;
}

/**********************************************************************************
 * Module name              : SetCounterValCapsense
 * Module ID                : 
 * Purpose of the module    : Set the Timer counter value
 * Author/s                 : PK
 * Date written             : 20/12/2017
 * Global Variables Referred: g_unTimer_Counter
 * Global Variables Modified: g_unTimer_Counter  
 * Functions called         : None
 * Arguments                : unClearcounter
 * Return Values            : None
 *********************************************************************************/
void SetCounterValCapsense(uint16 unClearcounter)
{
    g_unTimer_Counter_Capsense = unClearcounter;
}
/* [] END OF FILE */
